"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.organizationmanager.v1.idp.application.saml.application_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _AssignmentAction:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AssignmentActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AssignmentAction.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ASSIGNMENT_ACTION_UNSPECIFIED: _AssignmentAction.ValueType  # 0
    """The assignment action is not specified."""
    ADD: _AssignmentAction.ValueType  # 1
    """Add an assignment."""
    REMOVE: _AssignmentAction.ValueType  # 2
    """Remove an assignment."""

class AssignmentAction(_AssignmentAction, metaclass=_AssignmentActionEnumTypeWrapper):
    """Actions that can be performed on assignments."""

ASSIGNMENT_ACTION_UNSPECIFIED: AssignmentAction.ValueType  # 0
"""The assignment action is not specified."""
ADD: AssignmentAction.ValueType  # 1
"""Add an assignment."""
REMOVE: AssignmentAction.ValueType  # 2
"""Remove an assignment."""
global___AssignmentAction = AssignmentAction

@typing.final
class GetApplicationRequest(google.protobuf.message.Message):
    """Request to get a SAML application by ID."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    """ID of the SAML application to return."""
    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["application_id", b"application_id"]) -> None: ...

global___GetApplicationRequest = GetApplicationRequest

@typing.final
class ListApplicationsRequest(google.protobuf.message.Message):
    """Request to list SAML applications in an organization."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """ID of the organization to list applications in."""
    page_size: builtins.int
    """The maximum number of results per page to return."""
    page_token: builtins.str
    """Page token for pagination."""
    filter: builtins.str
    """A filter expression that filters resources listed in the response."""
    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "organization_id", b"organization_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListApplicationsRequest = ListApplicationsRequest

@typing.final
class ListApplicationsResponse(google.protobuf.message.Message):
    """Response message for [ApplicationService.List]."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list."""
    @property
    def applications(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.organizationmanager.v1.idp.application.saml.application_pb2.Application]:
        """List of SAML applications."""

    def __init__(
        self,
        *,
        applications: collections.abc.Iterable[yandex.cloud.organizationmanager.v1.idp.application.saml.application_pb2.Application] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["applications", b"applications", "next_page_token", b"next_page_token"]) -> None: ...

global___ListApplicationsResponse = ListApplicationsResponse

@typing.final
class CreateApplicationRequest(google.protobuf.message.Message):
    """Request to create a new SAML application."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SERVICE_PROVIDER_FIELD_NUMBER: builtins.int
    SECURITY_SETTINGS_FIELD_NUMBER: builtins.int
    ATTRIBUTE_MAPPING_FIELD_NUMBER: builtins.int
    GROUP_CLAIMS_SETTINGS_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """ID of the organization to create the application in."""
    name: builtins.str
    """Name of the SAML application."""
    description: builtins.str
    """Description of the SAML application."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `` key:value `` pairs."""

    @property
    def service_provider(self) -> yandex.cloud.organizationmanager.v1.idp.application.saml.application_pb2.ServiceProvider:
        """Service provider configuration for the SAML application."""

    @property
    def security_settings(self) -> global___SecuritySettingsSpec:
        """Security settings for the SAML application."""

    @property
    def attribute_mapping(self) -> global___AttributeMappingSpec:
        """Attribute mapping configuration for the SAML application."""

    @property
    def group_claims_settings(self) -> yandex.cloud.organizationmanager.v1.idp.application.saml.application_pb2.GroupClaimsSettings:
        """Group claims settings for the SAML application."""

    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        service_provider: yandex.cloud.organizationmanager.v1.idp.application.saml.application_pb2.ServiceProvider | None = ...,
        security_settings: global___SecuritySettingsSpec | None = ...,
        attribute_mapping: global___AttributeMappingSpec | None = ...,
        group_claims_settings: yandex.cloud.organizationmanager.v1.idp.application.saml.application_pb2.GroupClaimsSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute_mapping", b"attribute_mapping", "group_claims_settings", b"group_claims_settings", "security_settings", b"security_settings", "service_provider", b"service_provider"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute_mapping", b"attribute_mapping", "description", b"description", "group_claims_settings", b"group_claims_settings", "labels", b"labels", "name", b"name", "organization_id", b"organization_id", "security_settings", b"security_settings", "service_provider", b"service_provider"]) -> None: ...

global___CreateApplicationRequest = CreateApplicationRequest

@typing.final
class SecuritySettingsSpec(google.protobuf.message.Message):
    """Security settings specification for SAML application creation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIGNATURE_MODE_FIELD_NUMBER: builtins.int
    signature_mode: yandex.cloud.organizationmanager.v1.idp.application.saml.application_pb2.SecuritySettings.SignatureMode.ValueType
    """Signature mode for SAML assertions and responses."""
    def __init__(
        self,
        *,
        signature_mode: yandex.cloud.organizationmanager.v1.idp.application.saml.application_pb2.SecuritySettings.SignatureMode.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["signature_mode", b"signature_mode"]) -> None: ...

global___SecuritySettingsSpec = SecuritySettingsSpec

@typing.final
class NameIdSpec(google.protobuf.message.Message):
    """NameID specification for SAML application."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FORMAT_FIELD_NUMBER: builtins.int
    format: yandex.cloud.organizationmanager.v1.idp.application.saml.application_pb2.NameId.Format.ValueType
    """Format of the NameID."""
    def __init__(
        self,
        *,
        format: yandex.cloud.organizationmanager.v1.idp.application.saml.application_pb2.NameId.Format.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["format", b"format"]) -> None: ...

global___NameIdSpec = NameIdSpec

@typing.final
class AttributeMappingSpec(google.protobuf.message.Message):
    """Attribute mapping specification for SAML application."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_ID_FIELD_NUMBER: builtins.int
    ATTRIBUTES_FIELD_NUMBER: builtins.int
    @property
    def name_id(self) -> global___NameIdSpec:
        """NameID configuration."""

    @property
    def attributes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.organizationmanager.v1.idp.application.saml.application_pb2.Attribute]:
        """List of attribute mappings."""

    def __init__(
        self,
        *,
        name_id: global___NameIdSpec | None = ...,
        attributes: collections.abc.Iterable[yandex.cloud.organizationmanager.v1.idp.application.saml.application_pb2.Attribute] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["name_id", b"name_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attributes", b"attributes", "name_id", b"name_id"]) -> None: ...

global___AttributeMappingSpec = AttributeMappingSpec

@typing.final
class CreateApplicationMetadata(google.protobuf.message.Message):
    """Metadata for the [ApplicationService.Create] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    """ID of the SAML application that is being created."""
    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["application_id", b"application_id"]) -> None: ...

global___CreateApplicationMetadata = CreateApplicationMetadata

@typing.final
class UpdateApplicationRequest(google.protobuf.message.Message):
    """Request to update an existing SAML application."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SERVICE_PROVIDER_FIELD_NUMBER: builtins.int
    SECURITY_SETTINGS_FIELD_NUMBER: builtins.int
    ATTRIBUTE_MAPPING_FIELD_NUMBER: builtins.int
    GROUP_CLAIMS_SETTINGS_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    """ID of the SAML application to update."""
    name: builtins.str
    """New name for the SAML application."""
    description: builtins.str
    """New description for the SAML application."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the application are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """New resource labels as `` key:value `` pairs."""

    @property
    def service_provider(self) -> yandex.cloud.organizationmanager.v1.idp.application.saml.application_pb2.ServiceProvider:
        """New service provider configuration for the SAML application."""

    @property
    def security_settings(self) -> yandex.cloud.organizationmanager.v1.idp.application.saml.application_pb2.SecuritySettings:
        """New security settings for the SAML application."""

    @property
    def attribute_mapping(self) -> global___AttributeMappingSpec:
        """New attribute mapping configuration for the SAML application."""

    @property
    def group_claims_settings(self) -> yandex.cloud.organizationmanager.v1.idp.application.saml.application_pb2.GroupClaimsSettings:
        """New group claims settings for the SAML application."""

    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        service_provider: yandex.cloud.organizationmanager.v1.idp.application.saml.application_pb2.ServiceProvider | None = ...,
        security_settings: yandex.cloud.organizationmanager.v1.idp.application.saml.application_pb2.SecuritySettings | None = ...,
        attribute_mapping: global___AttributeMappingSpec | None = ...,
        group_claims_settings: yandex.cloud.organizationmanager.v1.idp.application.saml.application_pb2.GroupClaimsSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute_mapping", b"attribute_mapping", "group_claims_settings", b"group_claims_settings", "security_settings", b"security_settings", "service_provider", b"service_provider", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["application_id", b"application_id", "attribute_mapping", b"attribute_mapping", "description", b"description", "group_claims_settings", b"group_claims_settings", "labels", b"labels", "name", b"name", "security_settings", b"security_settings", "service_provider", b"service_provider", "update_mask", b"update_mask"]) -> None: ...

global___UpdateApplicationRequest = UpdateApplicationRequest

@typing.final
class UpdateApplicationMetadata(google.protobuf.message.Message):
    """Metadata for the [ApplicationService.Update] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    """ID of the SAML application that is being updated."""
    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["application_id", b"application_id"]) -> None: ...

global___UpdateApplicationMetadata = UpdateApplicationMetadata

@typing.final
class DeleteApplicationRequest(google.protobuf.message.Message):
    """Request to delete a SAML application."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    """ID of the SAML application to delete."""
    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["application_id", b"application_id"]) -> None: ...

global___DeleteApplicationRequest = DeleteApplicationRequest

@typing.final
class DeleteApplicationMetadata(google.protobuf.message.Message):
    """Metadata for the [ApplicationService.Delete] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    """ID of the SAML application that is being deleted."""
    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["application_id", b"application_id"]) -> None: ...

global___DeleteApplicationMetadata = DeleteApplicationMetadata

@typing.final
class SuspendApplicationRequest(google.protobuf.message.Message):
    """Request to suspend a SAML application."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    """ID of the SAML application to suspend."""
    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["application_id", b"application_id"]) -> None: ...

global___SuspendApplicationRequest = SuspendApplicationRequest

@typing.final
class SuspendApplicationMetadata(google.protobuf.message.Message):
    """Metadata for the [ApplicationService.Suspend] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    """ID of the SAML application that is being suspended."""
    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["application_id", b"application_id"]) -> None: ...

global___SuspendApplicationMetadata = SuspendApplicationMetadata

@typing.final
class ReactivateApplicationRequest(google.protobuf.message.Message):
    """Request to reactivate a suspended SAML application."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    """ID of the SAML application to reactivate."""
    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["application_id", b"application_id"]) -> None: ...

global___ReactivateApplicationRequest = ReactivateApplicationRequest

@typing.final
class ReactivateApplicationMetadata(google.protobuf.message.Message):
    """Metadata for the [ApplicationService.Reactivate] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    """ID of the SAML application that is being reactivated."""
    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["application_id", b"application_id"]) -> None: ...

global___ReactivateApplicationMetadata = ReactivateApplicationMetadata

@typing.final
class ListSupportedAttributeValuesRequest(google.protobuf.message.Message):
    """Request to list supported attribute values for SAML applications."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListSupportedAttributeValuesRequest = ListSupportedAttributeValuesRequest

@typing.final
class ListSupportedAttributeValuesResponse(google.protobuf.message.Message):
    """Response message for [ApplicationService.ListSupportedAttributeValues]."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUPPORTED_ATTRIBUTE_VALUES_FIELD_NUMBER: builtins.int
    @property
    def supported_attribute_values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SupportedAttributeValue]:
        """List of supported attribute values."""

    def __init__(
        self,
        *,
        supported_attribute_values: collections.abc.Iterable[global___SupportedAttributeValue] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["supported_attribute_values", b"supported_attribute_values"]) -> None: ...

global___ListSupportedAttributeValuesResponse = ListSupportedAttributeValuesResponse

@typing.final
class SupportedAttributeValue(google.protobuf.message.Message):
    """A supported attribute value for SAML applications."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.str
    """The attribute value."""
    def __init__(
        self,
        *,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["value", b"value"]) -> None: ...

global___SupportedAttributeValue = SupportedAttributeValue

@typing.final
class ListApplicationOperationsRequest(google.protobuf.message.Message):
    """Request to list operations for a SAML application."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    """ID of the SAML application to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page to return."""
    page_token: builtins.str
    """Page token for pagination."""
    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["application_id", b"application_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListApplicationOperationsRequest = ListApplicationOperationsRequest

@typing.final
class ListApplicationOperationsResponse(google.protobuf.message.Message):
    """Response message for [ApplicationService.ListOperations]."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list."""
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListApplicationOperationsResponse = ListApplicationOperationsResponse

@typing.final
class Assignment(google.protobuf.message.Message):
    """An assignment for a SAML application."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBJECT_ID_FIELD_NUMBER: builtins.int
    subject_id: builtins.str
    """ID of the subject being assigned."""
    def __init__(
        self,
        *,
        subject_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subject_id", b"subject_id"]) -> None: ...

global___Assignment = Assignment

@typing.final
class AssignmentDelta(google.protobuf.message.Message):
    """A delta operation on assignments."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    ASSIGNMENT_FIELD_NUMBER: builtins.int
    action: global___AssignmentAction.ValueType
    """Action to perform on the assignment."""
    @property
    def assignment(self) -> global___Assignment:
        """Assignment to perform the action on."""

    def __init__(
        self,
        *,
        action: global___AssignmentAction.ValueType = ...,
        assignment: global___Assignment | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["assignment", b"assignment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "assignment", b"assignment"]) -> None: ...

global___AssignmentDelta = AssignmentDelta

@typing.final
class UpdateAssignmentsResponse(google.protobuf.message.Message):
    """Response message for [ApplicationService.UpdateAssignments]."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ASSIGNMENT_DELTAS_FIELD_NUMBER: builtins.int
    @property
    def assignment_deltas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AssignmentDelta]:
        """List of assignment deltas that were applied."""

    def __init__(
        self,
        *,
        assignment_deltas: collections.abc.Iterable[global___AssignmentDelta] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["assignment_deltas", b"assignment_deltas"]) -> None: ...

global___UpdateAssignmentsResponse = UpdateAssignmentsResponse

@typing.final
class ListAssignmentsRequest(google.protobuf.message.Message):
    """Request to list assignments for a SAML application."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    """ID of the SAML application to list assignments for."""
    page_size: builtins.int
    """The maximum number of results per page to return."""
    page_token: builtins.str
    """Page token for pagination."""
    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["application_id", b"application_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListAssignmentsRequest = ListAssignmentsRequest

@typing.final
class ListAssignmentsResponse(google.protobuf.message.Message):
    """Response message for [ApplicationService.ListAssignments]."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ASSIGNMENTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list."""
    @property
    def assignments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Assignment]:
        """List of assignments."""

    def __init__(
        self,
        *,
        assignments: collections.abc.Iterable[global___Assignment] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["assignments", b"assignments", "next_page_token", b"next_page_token"]) -> None: ...

global___ListAssignmentsResponse = ListAssignmentsResponse

@typing.final
class UpdateAssignmentsRequest(google.protobuf.message.Message):
    """Request to update assignments for a SAML application."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    ASSIGNMENT_DELTAS_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    """ID of the SAML application to update assignments for."""
    @property
    def assignment_deltas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AssignmentDelta]:
        """List of assignment deltas to apply."""

    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
        assignment_deltas: collections.abc.Iterable[global___AssignmentDelta] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["application_id", b"application_id", "assignment_deltas", b"assignment_deltas"]) -> None: ...

global___UpdateAssignmentsRequest = UpdateAssignmentsRequest

@typing.final
class UpdateAssignmentsMetadata(google.protobuf.message.Message):
    """Metadata for the [ApplicationService.UpdateAssignments] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    """ID of the SAML application whose assignments are being updated."""
    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["application_id", b"application_id"]) -> None: ...

global___UpdateAssignmentsMetadata = UpdateAssignmentsMetadata



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/organizationmanager/v1/idp/synchronization_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/organizationmanager/v1/idp/synchronization_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.organizationmanager.v1.idp import synchronization_settings_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__settings__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEyandex/cloud/organizationmanager/v1/idp/synchronization_service.proto\x12\'yandex.cloud.organizationmanager.v1.idp\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x46yandex/cloud/organizationmanager/v1/idp/synchronization_settings.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1egoogle/protobuf/duration.proto\x1a google/protobuf/field_mask.proto\"\x8a\x05\n$CreateSynchronizationSettingsRequest\x12*\n\x14subject_container_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12T\n\x06\x66ilter\x18\x02 \x01(\x0b\x32>.yandex.cloud.organizationmanager.v1.idp.SynchronizationFilterB\x04\xe8\xc7\x31\x01\x12%\n\x12replacement_domain\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05\x30-253\x12Y\n\x14remove_user_behavior\x18\x04 \x01(\x0e\x32;.yandex.cloud.organizationmanager.v1.idp.RemoveUserBehavior\x12G\n\x18synchronization_interval\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\xc7\x31\x06\x31\x35m-6h\x12\x1e\n\x16\x61llow_to_capture_users\x18\x06 \x01(\x08\x12\x1f\n\x17\x61llow_to_capture_groups\x18\x07 \x01(\x08\x12h\n\x17user_attribute_mappings\x18\x08 \x03(\x0b\x32=.yandex.cloud.organizationmanager.v1.idp.UserAttributeMappingB\x08\x82\xc8\x31\x04<=50\x12j\n\x18group_attribute_mappings\x18\t \x03(\x0b\x32>.yandex.cloud.organizationmanager.v1.idp.GroupAttributeMappingB\x08\x82\xc8\x31\x04<=50\"E\n%CreateSynchronizationSettingsMetadata\x12\x1c\n\x14subject_container_id\x18\x01 \x01(\t\"\xb5\x05\n$UpdateSynchronizationSettingsRequest\x12*\n\x14subject_container_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12N\n\x06\x66ilter\x18\x02 \x01(\x0b\x32>.yandex.cloud.organizationmanager.v1.idp.SynchronizationFilter\x12%\n\x12replacement_domain\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05\x30-253\x12Y\n\x14remove_user_behavior\x18\x04 \x01(\x0e\x32;.yandex.cloud.organizationmanager.v1.idp.RemoveUserBehavior\x12G\n\x18synchronization_interval\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\xc7\x31\x06\x31\x35m-6h\x12\x1e\n\x16\x61llow_to_capture_users\x18\x06 \x01(\x08\x12\x1f\n\x17\x61llow_to_capture_groups\x18\x07 \x01(\x08\x12h\n\x17user_attribute_mappings\x18\x08 \x03(\x0b\x32=.yandex.cloud.organizationmanager.v1.idp.UserAttributeMappingB\x08\x82\xc8\x31\x04<=50\x12j\n\x18group_attribute_mappings\x18\t \x03(\x0b\x32>.yandex.cloud.organizationmanager.v1.idp.GroupAttributeMappingB\x08\x82\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\n \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"E\n%UpdateSynchronizationSettingsMetadata\x12\x1c\n\x14subject_container_id\x18\x01 \x01(\t\"R\n$DeleteSynchronizationSettingsRequest\x12*\n\x14subject_container_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"E\n%DeleteSynchronizationSettingsMetadata\x12\x1c\n\x14subject_container_id\x18\x01 \x01(\t\"O\n!GetSynchronizationSettingsRequest\x12*\n\x14subject_container_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"q\n\x1eListSupportedAttributesRequest\x12O\n\x06\x66lavor\x18\x01 \x01(\x0e\x32\x39.yandex.cloud.organizationmanager.v1.idp.AttributesFlavorB\x04\xe8\xc7\x31\x01\"\xeb\x01\n\x1fListSupportedAttributesResponse\x12\x62\n\x19user_supported_attributes\x18\x01 \x03(\x0b\x32?.yandex.cloud.organizationmanager.v1.idp.UserSupportedAttribute\x12\x64\n\x1agroup_supported_attributes\x18\x02 \x03(\x0b\x32@.yandex.cloud.organizationmanager.v1.idp.GroupSupportedAttribute\"\xc6\x01\n\x16UserSupportedAttribute\x12V\n\x10target_attribute\x18\x01 \x01(\x0e\x32<.yandex.cloud.organizationmanager.v1.idp.UserTargetAttribute\x12T\n\x11source_attributes\x18\x02 \x03(\x0b\x32\x39.yandex.cloud.organizationmanager.v1.idp.SourceAttributes\"\xc8\x01\n\x17GroupSupportedAttribute\x12W\n\x10target_attribute\x18\x01 \x01(\x0e\x32=.yandex.cloud.organizationmanager.v1.idp.GroupTargetAttribute\x12T\n\x11source_attributes\x18\x02 \x03(\x0b\x32\x39.yandex.cloud.organizationmanager.v1.idp.SourceAttributes\"j\n\x10SourceAttributes\x12\x42\n\x04type\x18\x01 \x01(\x0e\x32\x34.yandex.cloud.organizationmanager.v1.idp.MappingType\x12\x12\n\nattributes\x18\x02 \x03(\t\"\xc5\x01\n\x1aSetReplicationTokenRequest\x12*\n\x14subject_container_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12)\n\x11replication_token\x18\x02 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=1000\x12P\n\x0csession_type\x18\x03 \x01(\x0e\x32\x34.yandex.cloud.organizationmanager.v1.idp.SessionTypeB\x04\xe8\xc7\x31\x01\";\n\x1bSetReplicationTokenMetadata\x12\x1c\n\x14subject_container_id\x18\x01 \x01(\t\"J\n\x1cResetReplicationTokenRequest\x12*\n\x14subject_container_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"=\n\x1dResetReplicationTokenMetadata\x12\x1c\n\x14subject_container_id\x18\x01 \x01(\t*K\n\x10\x41ttributesFlavor\x12!\n\x1d\x41TTRIBUTES_FLAVOR_UNSPECIFIED\x10\x00\x12\x14\n\x10\x41\x43TIVE_DIRECTORY\x10\x01\x32\xb5\x0f\n\x16SynchronizationService\x12\x8c\x02\n\x13SetReplicationToken\x12\x43.yandex.cloud.organizationmanager.v1.idp.SetReplicationTokenRequest\x1a!.yandex.cloud.operation.Operation\"\x8c\x01\xb2\xd2*4\n\x1bSetReplicationTokenMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02N\"I/organization-manager/v1/idp/synchronization-settings:setReplicationToken:\x01*\x12\x94\x02\n\x15ResetReplicationToken\x12\x45.yandex.cloud.organizationmanager.v1.idp.ResetReplicationTokenRequest\x1a!.yandex.cloud.operation.Operation\"\x90\x01\xb2\xd2*6\n\x1dResetReplicationTokenMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02P\"K/organization-manager/v1/idp/synchronization-settings:resetReplicationToken:\x01*\x12\x98\x02\n\x1d\x43reateSynchronizationSettings\x12M.yandex.cloud.organizationmanager.v1.idp.CreateSynchronizationSettingsRequest\x1a!.yandex.cloud.operation.Operation\"\x84\x01\xb2\xd2*@\n%CreateSynchronizationSettingsMetadata\x12\x17SynchronizationSettings\x82\xd3\xe4\x93\x02:\"5/organization-manager/v1/idp/synchronization-settings:\x01*\x12\xaf\x02\n\x1dUpdateSynchronizationSettings\x12M.yandex.cloud.organizationmanager.v1.idp.UpdateSynchronizationSettingsRequest\x1a!.yandex.cloud.operation.Operation\"\x9b\x01\xb2\xd2*@\n%UpdateSynchronizationSettingsMetadata\x12\x17SynchronizationSettings\x82\xd3\xe4\x93\x02Q2L/organization-manager/v1/idp/synchronization-settings/{subject_container_id}:\x01*\x12\xaa\x02\n\x1d\x44\x65leteSynchronizationSettings\x12M.yandex.cloud.organizationmanager.v1.idp.DeleteSynchronizationSettingsRequest\x1a!.yandex.cloud.operation.Operation\"\x96\x01\xb2\xd2*>\n%DeleteSynchronizationSettingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02N*L/organization-manager/v1/idp/synchronization-settings/{subject_container_id}\x12\x80\x02\n\x1aGetSynchronizationSettings\x12J.yandex.cloud.organizationmanager.v1.idp.GetSynchronizationSettingsRequest\x1a@.yandex.cloud.organizationmanager.v1.idp.SynchronizationSettings\"T\x82\xd3\xe4\x93\x02N\x12L/organization-manager/v1/idp/synchronization-settings/{subject_container_id}\x12\xf7\x01\n\x17ListSupportedAttributes\x12G.yandex.cloud.organizationmanager.v1.idp.ListSupportedAttributesRequest\x1aH.yandex.cloud.organizationmanager.v1.idp.ListSupportedAttributesResponse\"I\x82\xd3\xe4\x93\x02\x43\x12\x41/organization-manager/v1/idp/synchronization-supported-attributesB~\n+yandex.cloud.api.organizationmanager.v1.idpZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp;idpb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+yandex.cloud.api.organizationmanager.v1.idpZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp;idp'
  _globals['_CREATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['subject_container_id']._loaded_options = None
  _globals['_CREATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['subject_container_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_CREATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['filter']._serialized_options = b'\350\3071\001'
  _globals['_CREATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['replacement_domain']._loaded_options = None
  _globals['_CREATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['replacement_domain']._serialized_options = b'\212\3101\0050-253'
  _globals['_CREATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['synchronization_interval']._loaded_options = None
  _globals['_CREATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['synchronization_interval']._serialized_options = b'\372\3071\00615m-6h'
  _globals['_CREATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['user_attribute_mappings']._loaded_options = None
  _globals['_CREATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['user_attribute_mappings']._serialized_options = b'\202\3101\004<=50'
  _globals['_CREATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['group_attribute_mappings']._loaded_options = None
  _globals['_CREATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['group_attribute_mappings']._serialized_options = b'\202\3101\004<=50'
  _globals['_UPDATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['subject_container_id']._loaded_options = None
  _globals['_UPDATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['subject_container_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['replacement_domain']._loaded_options = None
  _globals['_UPDATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['replacement_domain']._serialized_options = b'\212\3101\0050-253'
  _globals['_UPDATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['synchronization_interval']._loaded_options = None
  _globals['_UPDATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['synchronization_interval']._serialized_options = b'\372\3071\00615m-6h'
  _globals['_UPDATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['user_attribute_mappings']._loaded_options = None
  _globals['_UPDATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['user_attribute_mappings']._serialized_options = b'\202\3101\004<=50'
  _globals['_UPDATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['group_attribute_mappings']._loaded_options = None
  _globals['_UPDATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['group_attribute_mappings']._serialized_options = b'\202\3101\004<=50'
  _globals['_DELETESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['subject_container_id']._loaded_options = None
  _globals['_DELETESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['subject_container_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETSYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['subject_container_id']._loaded_options = None
  _globals['_GETSYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['subject_container_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTSUPPORTEDATTRIBUTESREQUEST'].fields_by_name['flavor']._loaded_options = None
  _globals['_LISTSUPPORTEDATTRIBUTESREQUEST'].fields_by_name['flavor']._serialized_options = b'\350\3071\001'
  _globals['_SETREPLICATIONTOKENREQUEST'].fields_by_name['subject_container_id']._loaded_options = None
  _globals['_SETREPLICATIONTOKENREQUEST'].fields_by_name['subject_container_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SETREPLICATIONTOKENREQUEST'].fields_by_name['replication_token']._loaded_options = None
  _globals['_SETREPLICATIONTOKENREQUEST'].fields_by_name['replication_token']._serialized_options = b'\350\3071\001\212\3101\006<=1000'
  _globals['_SETREPLICATIONTOKENREQUEST'].fields_by_name['session_type']._loaded_options = None
  _globals['_SETREPLICATIONTOKENREQUEST'].fields_by_name['session_type']._serialized_options = b'\350\3071\001'
  _globals['_RESETREPLICATIONTOKENREQUEST'].fields_by_name['subject_container_id']._loaded_options = None
  _globals['_RESETREPLICATIONTOKENREQUEST'].fields_by_name['subject_container_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SYNCHRONIZATIONSERVICE'].methods_by_name['SetReplicationToken']._loaded_options = None
  _globals['_SYNCHRONIZATIONSERVICE'].methods_by_name['SetReplicationToken']._serialized_options = b'\262\322*4\n\033SetReplicationTokenMetadata\022\025google.protobuf.Empty\202\323\344\223\002N\"I/organization-manager/v1/idp/synchronization-settings:setReplicationToken:\001*'
  _globals['_SYNCHRONIZATIONSERVICE'].methods_by_name['ResetReplicationToken']._loaded_options = None
  _globals['_SYNCHRONIZATIONSERVICE'].methods_by_name['ResetReplicationToken']._serialized_options = b'\262\322*6\n\035ResetReplicationTokenMetadata\022\025google.protobuf.Empty\202\323\344\223\002P\"K/organization-manager/v1/idp/synchronization-settings:resetReplicationToken:\001*'
  _globals['_SYNCHRONIZATIONSERVICE'].methods_by_name['CreateSynchronizationSettings']._loaded_options = None
  _globals['_SYNCHRONIZATIONSERVICE'].methods_by_name['CreateSynchronizationSettings']._serialized_options = b'\262\322*@\n%CreateSynchronizationSettingsMetadata\022\027SynchronizationSettings\202\323\344\223\002:\"5/organization-manager/v1/idp/synchronization-settings:\001*'
  _globals['_SYNCHRONIZATIONSERVICE'].methods_by_name['UpdateSynchronizationSettings']._loaded_options = None
  _globals['_SYNCHRONIZATIONSERVICE'].methods_by_name['UpdateSynchronizationSettings']._serialized_options = b'\262\322*@\n%UpdateSynchronizationSettingsMetadata\022\027SynchronizationSettings\202\323\344\223\002Q2L/organization-manager/v1/idp/synchronization-settings/{subject_container_id}:\001*'
  _globals['_SYNCHRONIZATIONSERVICE'].methods_by_name['DeleteSynchronizationSettings']._loaded_options = None
  _globals['_SYNCHRONIZATIONSERVICE'].methods_by_name['DeleteSynchronizationSettings']._serialized_options = b'\262\322*>\n%DeleteSynchronizationSettingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002N*L/organization-manager/v1/idp/synchronization-settings/{subject_container_id}'
  _globals['_SYNCHRONIZATIONSERVICE'].methods_by_name['GetSynchronizationSettings']._loaded_options = None
  _globals['_SYNCHRONIZATIONSERVICE'].methods_by_name['GetSynchronizationSettings']._serialized_options = b'\202\323\344\223\002N\022L/organization-manager/v1/idp/synchronization-settings/{subject_container_id}'
  _globals['_SYNCHRONIZATIONSERVICE'].methods_by_name['ListSupportedAttributes']._loaded_options = None
  _globals['_SYNCHRONIZATIONSERVICE'].methods_by_name['ListSupportedAttributes']._serialized_options = b'\202\323\344\223\002C\022A/organization-manager/v1/idp/synchronization-supported-attributes'
  _globals['_ATTRIBUTESFLAVOR']._serialized_start=3379
  _globals['_ATTRIBUTESFLAVOR']._serialized_end=3454
  _globals['_CREATESYNCHRONIZATIONSETTINGSREQUEST']._serialized_start=388
  _globals['_CREATESYNCHRONIZATIONSETTINGSREQUEST']._serialized_end=1038
  _globals['_CREATESYNCHRONIZATIONSETTINGSMETADATA']._serialized_start=1040
  _globals['_CREATESYNCHRONIZATIONSETTINGSMETADATA']._serialized_end=1109
  _globals['_UPDATESYNCHRONIZATIONSETTINGSREQUEST']._serialized_start=1112
  _globals['_UPDATESYNCHRONIZATIONSETTINGSREQUEST']._serialized_end=1805
  _globals['_UPDATESYNCHRONIZATIONSETTINGSMETADATA']._serialized_start=1807
  _globals['_UPDATESYNCHRONIZATIONSETTINGSMETADATA']._serialized_end=1876
  _globals['_DELETESYNCHRONIZATIONSETTINGSREQUEST']._serialized_start=1878
  _globals['_DELETESYNCHRONIZATIONSETTINGSREQUEST']._serialized_end=1960
  _globals['_DELETESYNCHRONIZATIONSETTINGSMETADATA']._serialized_start=1962
  _globals['_DELETESYNCHRONIZATIONSETTINGSMETADATA']._serialized_end=2031
  _globals['_GETSYNCHRONIZATIONSETTINGSREQUEST']._serialized_start=2033
  _globals['_GETSYNCHRONIZATIONSETTINGSREQUEST']._serialized_end=2112
  _globals['_LISTSUPPORTEDATTRIBUTESREQUEST']._serialized_start=2114
  _globals['_LISTSUPPORTEDATTRIBUTESREQUEST']._serialized_end=2227
  _globals['_LISTSUPPORTEDATTRIBUTESRESPONSE']._serialized_start=2230
  _globals['_LISTSUPPORTEDATTRIBUTESRESPONSE']._serialized_end=2465
  _globals['_USERSUPPORTEDATTRIBUTE']._serialized_start=2468
  _globals['_USERSUPPORTEDATTRIBUTE']._serialized_end=2666
  _globals['_GROUPSUPPORTEDATTRIBUTE']._serialized_start=2669
  _globals['_GROUPSUPPORTEDATTRIBUTE']._serialized_end=2869
  _globals['_SOURCEATTRIBUTES']._serialized_start=2871
  _globals['_SOURCEATTRIBUTES']._serialized_end=2977
  _globals['_SETREPLICATIONTOKENREQUEST']._serialized_start=2980
  _globals['_SETREPLICATIONTOKENREQUEST']._serialized_end=3177
  _globals['_SETREPLICATIONTOKENMETADATA']._serialized_start=3179
  _globals['_SETREPLICATIONTOKENMETADATA']._serialized_end=3238
  _globals['_RESETREPLICATIONTOKENREQUEST']._serialized_start=3240
  _globals['_RESETREPLICATIONTOKENREQUEST']._serialized_end=3314
  _globals['_RESETREPLICATIONTOKENMETADATA']._serialized_start=3316
  _globals['_RESETREPLICATIONTOKENMETADATA']._serialized_end=3377
  _globals['_SYNCHRONIZATIONSERVICE']._serialized_start=3457
  _globals['_SYNCHRONIZATIONSERVICE']._serialized_end=5430
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/marketplace/stacklandlicenseapi/v1/sync.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/marketplace/stacklandlicenseapi/v1/sync.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/marketplace/stacklandlicenseapi/v1/sync.proto\x12/yandex.cloud.marketplace.stacklandlicenseapi.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xf4\x03\n\nUsageEntry\x12&\n\x0finstallation_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=100\x12R\n\x0cproduct_type\x18\x02 \x01(\x0e\x32<.yandex.cloud.marketplace.stacklandlicenseapi.v1.ProductType\x12\x1b\n\x04type\x18\x03 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=100\x12\r\n\x05usage\x18\x04 \x01(\x03\x12\x33\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12\'\n\x14hardware_fingerprint\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=500\x12!\n\nlicense_id\x18\x07 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=100\x12\x17\n\x0frequested_value\x18\x08 \x01(\x03\x12:\n\x10server_timestamp\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12$\n\x10prev_record_hash\x18\n \x01(\tB\n\xe8\xc7\x31\x01\x8a\xc8\x31\x02\x36\x34\x12\x1f\n\x0brecord_hash\x18\x0b \x01(\tB\n\xe8\xc7\x31\x01\x8a\xc8\x31\x02\x36\x34\x12!\n\tsignature\x18\x0c \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=1000\"+\n\x0cLicenseLimit\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x03\"\xe8\x02\n\x07License\x12\x12\n\nlicense_id\x18\x01 \x01(\t\x12R\n\x0cproduct_type\x18\x02 \x01(\x0e\x32<.yandex.cloud.marketplace.stacklandlicenseapi.v1.ProductType\x12\x17\n\x0forganization_id\x18\x03 \x01(\t\x12\x1a\n\x12\x62illing_account_id\x18\x04 \x01(\t\x12-\n\tissued_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bvalid_until\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12M\n\x06limits\x18\x07 \x03(\x0b\x32=.yandex.cloud.marketplace.stacklandlicenseapi.v1.LicenseLimit\x12\x11\n\tsignature\x18\x08 \x01(\t\"\xe0\x01\n\x0bSyncRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12(\n\x12\x62illing_account_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12(\n\x11license_server_id\x18\x03 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=100\x12V\n\x05usage\x18\x04 \x03(\x0b\x32;.yandex.cloud.marketplace.stacklandlicenseapi.v1.UsageEntryB\n\x82\xc8\x31\x06<=1000\"\xc0\x01\n\x0fSyncUsageResult\x12J\n\x08licenses\x18\x01 \x03(\x0b\x32\x38.yandex.cloud.marketplace.stacklandlicenseapi.v1.License\x12P\n\x0bsync_status\x18\x02 \x01(\x0e\x32;.yandex.cloud.marketplace.stacklandlicenseapi.v1.SyncStatus\x12\x0f\n\x07message\x18\x03 \x01(\t\"c\n\x11SyncUsageMetadata\x12\x17\n\x0forganization_id\x18\x01 \x01(\t\x12\x1a\n\x12\x62illing_account_id\x18\x02 \x01(\t\x12\x19\n\x11license_server_id\x18\x03 \x01(\t*\xba\x01\n\x0bProductType\x12\x1c\n\x18PRODUCT_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16PRODUCT_TYPE_STACKLAND\x10\x01\x12\x19\n\x15PRODUCT_TYPE_DATALENS\x10\x02\x12\x1a\n\x16PRODUCT_TYPE_AI_STUDIO\x10\x03\x12\x1c\n\x18PRODUCT_TYPE_SPEECHSENSE\x10\x04\x12\x1c\n\x18PRODUCT_TYPE_ROBOTICS_AI\x10\x05*I\n\nSyncStatus\x12\x1b\n\x17SYNC_STATUS_UNSPECIFIED\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x0b\n\x07WARNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x42\x9e\x01\n3yandex.cloud.api.marketplace.stacklandlicenseapi.v1Zggithub.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/stacklandlicenseapi/v1;stacklandlicenseapib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.marketplace.stacklandlicenseapi.v1.sync_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n3yandex.cloud.api.marketplace.stacklandlicenseapi.v1Zggithub.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/stacklandlicenseapi/v1;stacklandlicenseapi'
  _globals['_USAGEENTRY'].fields_by_name['installation_id']._loaded_options = None
  _globals['_USAGEENTRY'].fields_by_name['installation_id']._serialized_options = b'\350\3071\001\212\3101\005<=100'
  _globals['_USAGEENTRY'].fields_by_name['type']._loaded_options = None
  _globals['_USAGEENTRY'].fields_by_name['type']._serialized_options = b'\350\3071\001\212\3101\005<=100'
  _globals['_USAGEENTRY'].fields_by_name['timestamp']._loaded_options = None
  _globals['_USAGEENTRY'].fields_by_name['timestamp']._serialized_options = b'\350\3071\001'
  _globals['_USAGEENTRY'].fields_by_name['hardware_fingerprint']._loaded_options = None
  _globals['_USAGEENTRY'].fields_by_name['hardware_fingerprint']._serialized_options = b'\212\3101\005<=500'
  _globals['_USAGEENTRY'].fields_by_name['license_id']._loaded_options = None
  _globals['_USAGEENTRY'].fields_by_name['license_id']._serialized_options = b'\350\3071\001\212\3101\005<=100'
  _globals['_USAGEENTRY'].fields_by_name['server_timestamp']._loaded_options = None
  _globals['_USAGEENTRY'].fields_by_name['server_timestamp']._serialized_options = b'\350\3071\001'
  _globals['_USAGEENTRY'].fields_by_name['prev_record_hash']._loaded_options = None
  _globals['_USAGEENTRY'].fields_by_name['prev_record_hash']._serialized_options = b'\350\3071\001\212\3101\00264'
  _globals['_USAGEENTRY'].fields_by_name['record_hash']._loaded_options = None
  _globals['_USAGEENTRY'].fields_by_name['record_hash']._serialized_options = b'\350\3071\001\212\3101\00264'
  _globals['_USAGEENTRY'].fields_by_name['signature']._loaded_options = None
  _globals['_USAGEENTRY'].fields_by_name['signature']._serialized_options = b'\350\3071\001\212\3101\006<=1000'
  _globals['_SYNCREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_SYNCREQUEST'].fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SYNCREQUEST'].fields_by_name['billing_account_id']._loaded_options = None
  _globals['_SYNCREQUEST'].fields_by_name['billing_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SYNCREQUEST'].fields_by_name['license_server_id']._loaded_options = None
  _globals['_SYNCREQUEST'].fields_by_name['license_server_id']._serialized_options = b'\350\3071\001\212\3101\005<=100'
  _globals['_SYNCREQUEST'].fields_by_name['usage']._loaded_options = None
  _globals['_SYNCREQUEST'].fields_by_name['usage']._serialized_options = b'\202\3101\006<=1000'
  _globals['_PRODUCTTYPE']._serialized_start=1610
  _globals['_PRODUCTTYPE']._serialized_end=1796
  _globals['_SYNCSTATUS']._serialized_start=1798
  _globals['_SYNCSTATUS']._serialized_end=1871
  _globals['_USAGEENTRY']._serialized_start=176
  _globals['_USAGEENTRY']._serialized_end=676
  _globals['_LICENSELIMIT']._serialized_start=678
  _globals['_LICENSELIMIT']._serialized_end=721
  _globals['_LICENSE']._serialized_start=724
  _globals['_LICENSE']._serialized_end=1084
  _globals['_SYNCREQUEST']._serialized_start=1087
  _globals['_SYNCREQUEST']._serialized_end=1311
  _globals['_SYNCUSAGERESULT']._serialized_start=1314
  _globals['_SYNCUSAGERESULT']._serialized_end=1506
  _globals['_SYNCUSAGEMETADATA']._serialized_start=1508
  _globals['_SYNCUSAGEMETADATA']._serialized_end=1607
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import yandex.cloud.billing.usage_records.v1.billing_types_pb2
import yandex.cloud.billing.usage_records.v1.common_types_pb2
import yandex.cloud.billing.usage_records.v1.consumption_core_pb2
import yandex.cloud.billing.usage_records.v1.credit_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class UsageReportRequest(google.protobuf.message.Message):
    """Request for retrieving usage report data.

    This message defines the parameters for requesting usage reports across
    all ConsumptionCoreService methods. It supports filtering by various
    entity types and specifying the time range and aggregation period.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> yandex.cloud.billing.usage_records.v1.billing_types_pb2.LabelList: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: yandex.cloud.billing.usage_records.v1.billing_types_pb2.LabelList | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    BILLING_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    START_DATE_FIELD_NUMBER: builtins.int
    END_DATE_FIELD_NUMBER: builtins.int
    CLOUD_IDS_FIELD_NUMBER: builtins.int
    FOLDER_IDS_FIELD_NUMBER: builtins.int
    SERVICE_IDS_FIELD_NUMBER: builtins.int
    SKU_IDS_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    RESOURCE_IDS_FIELD_NUMBER: builtins.int
    AGGREGATION_PERIOD_FIELD_NUMBER: builtins.int
    billing_account_id: builtins.str
    """Required. Billing account identifier."""
    aggregation_period: yandex.cloud.billing.usage_records.v1.common_types_pb2.TimeGrouping.ValueType
    """Note on filter combinations: When multiple filter types are specified (cloud_ids, folder_ids,
    service_ids, sku_ids, labels, resource_ids), they are combined with AND logic. For example,
    if both cloud_ids and service_ids are provided, the results will only include data that
    matches both the specified clouds AND the specified services.

    The billing currency for the report is determined automatically based on the billing account.
    All monetary values in the response will be in this currency.

    Optional. Aggregation granularity for the report, controlling how data points are grouped
    in time series results. Available options include:
    - DAY: Group metrics by day, providing daily breakdowns
    - WEEK: Group metrics by week, providing weekly breakdowns
    - MONTH: Group metrics by month, providing monthly breakdowns
    - QUARTER: Group metrics by quarter, providing quarterly breakdowns
    - YEAR: Group metrics by year, providing yearly breakdowns

    This setting affects the time series data returned in the periodic field of each entity.
    If omitted, the service will typically use DAY as the default granularity.
    """
    @property
    def start_date(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Required. Inclusive start date for metrics selection (UTC).
        This timestamp defines the beginning of the reporting period.
        All usage data starting from this timestamp will be included in the report.
        Note: The time component (hours/minutes/seconds) is ignored since the smallest
        aggregation period is a day. For example, both 2023-04-15T00:00:00 and
        2023-04-15T23:59:59 will include the entire day of April 15, 2023.
        For best results, align with natural time boundaries (start of day, month)
        based on your aggregation_period value.
        """

    @property
    def end_date(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Required. Inclusive end date for metrics selection (UTC).
        This timestamp defines the end of the reporting period.
        All usage data up to and including this timestamp will be included in the report.
        Note: The time component (hours/minutes/seconds) is ignored since the smallest
        aggregation period is a day. For example, both 2023-04-15T00:00:00 and
        2023-04-15T23:59:59 will include the entire day of April 15, 2023.
        For best results, align with natural time boundaries (end of day, month)
        based on your aggregation_period value.
        """

    @property
    def cloud_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Optional. List of cloud IDs to filter the data.
        If specified, only usage data from these clouds will be included in the report.
        If omitted, data from all clouds available to the billing account will be included.
        The filter is applied with OR logic (results include data matching any of the specified cloud IDs).
        """

    @property
    def folder_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Optional. List of folder IDs to filter the data.
        If specified, only usage data from these folders will be included in the report.
        If omitted, data from all folders available to the billing account will be included.
        The filter is applied with OR logic (results include data matching any of the specified folder IDs).
        """

    @property
    def service_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Optional. List of Service IDs to filter the data.
        If specified, only usage data from these services (e.g., Compute, Storage, AI) will be included.
        If omitted, data from all services used by the billing account will be included.
        The filter is applied with OR logic (results include data matching any of the specified service IDs).
        """

    @property
    def sku_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Optional. List of SKU (Stock Keeping Unit) IDs to filter the data.
        If specified, only usage data from these specific SKUs will be included.
        If omitted, data from all SKUs used by the billing account will be included.
        The filter is applied with OR logic (results include data matching any of the specified SKU IDs).
        """

    @property
    def labels(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, yandex.cloud.billing.usage_records.v1.billing_types_pb2.LabelList]:
        """Optional. Filter by labels: key is label key (e.g., "env", "team", "region"),
        value is list of label values to match (e.g., ["prod", "stage"] for key "env").
        This allows filtering resources based on their attached labels.

        Example: To filter resources that have either (env=prod OR env=test) AND (team=finance),
        use the following filter:
        {
          "env": { "values": ["prod", "test"] },
          "team": { "values": ["finance"] }
        }

        Note: The filter logic is (value1 OR value2 OR ...) for each key,
        and (key1 AND key2 AND ...) between different keys.
        """

    @property
    def resource_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Optional. List of resource IDs to filter the data.
        If specified, only usage data from these specific resources (e.g., individual VMs, disks) will be included.
        If omitted, data from all resources used by the billing account will be included.
        Filter is applied with OR logic (results include data matching any of the specified resource IDs).
        """

    def __init__(
        self,
        *,
        billing_account_id: builtins.str = ...,
        start_date: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        end_date: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        cloud_ids: collections.abc.Iterable[builtins.str] | None = ...,
        folder_ids: collections.abc.Iterable[builtins.str] | None = ...,
        service_ids: collections.abc.Iterable[builtins.str] | None = ...,
        sku_ids: collections.abc.Iterable[builtins.str] | None = ...,
        labels: collections.abc.Mapping[builtins.str, yandex.cloud.billing.usage_records.v1.billing_types_pb2.LabelList] | None = ...,
        resource_ids: collections.abc.Iterable[builtins.str] | None = ...,
        aggregation_period: yandex.cloud.billing.usage_records.v1.common_types_pb2.TimeGrouping.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["end_date", b"end_date", "start_date", b"start_date"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["aggregation_period", b"aggregation_period", "billing_account_id", b"billing_account_id", "cloud_ids", b"cloud_ids", "end_date", b"end_date", "folder_ids", b"folder_ids", "labels", b"labels", "resource_ids", b"resource_ids", "service_ids", b"service_ids", "sku_ids", b"sku_ids", "start_date", b"start_date"]) -> None: ...

global___UsageReportRequest = UsageReportRequest

@typing.final
class BillingAccountUsageReportResponse(google.protobuf.message.Message):
    """Response for usage report requests by billing account.

    Contains aggregated usage, cost, and credit information for a billing account,
    with both summary totals and detailed breakdowns by billing account entity.
    The response includes:
    1. Overall totals for the entire period (cost, credits, expense)
    2. Entity-level totals for the specified billing account
    3. Time series breakdown for the billing account according to the requested aggregation period
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CURRENCY_FIELD_NUMBER: builtins.int
    COST_FIELD_NUMBER: builtins.int
    CREDIT_DETAILS_FIELD_NUMBER: builtins.int
    EXPENSE_FIELD_NUMBER: builtins.int
    ENTITIES_DATA_FIELD_NUMBER: builtins.int
    currency: yandex.cloud.billing.usage_records.v1.common_types_pb2.Currency.ValueType
    """Currency code (e.g., "RUB", "USD") for all monetary values in the response.
    Determined by the billing account's settings.
    """
    @property
    def cost(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Total usage cost for the selected time period.
        This represents the raw cost before any credits or discounts are applied.
        Calculated based on the resource consumption and the corresponding price rates.
        """

    @property
    def credit_details(self) -> yandex.cloud.billing.usage_records.v1.credit_pb2.CreditDetails:
        """Total credits (monetary grants, volume incentives, committed use discounts, and free credits) applied in the selected period.
        Contains a detailed breakdown of all credit types that reduced the final billable amount.
        """

    @property
    def expense(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Total expense (including cost and credit) for the selected time period.
        This is the final billable amount after all credits have been applied.
        Formula: expense = cost - sum of all credits.
        """

    @property
    def entities_data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.billing.usage_records.v1.consumption_core_pb2.BillingAccountUsageReportEntityData]:
        """Detailed usage and billing data for the specified billing account entity.
        This field contains a structured breakdown of costs, credits, and expenses
        for the requested billing account, including:
        1. Entity-level totals for the entire period (cost, credits, expense)
        2. Time series data broken down by the specified aggregation period (day/week/month/quarter/year)
        This represents the second and third levels in the overall three-level response structure.
        """

    def __init__(
        self,
        *,
        currency: yandex.cloud.billing.usage_records.v1.common_types_pb2.Currency.ValueType = ...,
        cost: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        credit_details: yandex.cloud.billing.usage_records.v1.credit_pb2.CreditDetails | None = ...,
        expense: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        entities_data: collections.abc.Iterable[yandex.cloud.billing.usage_records.v1.consumption_core_pb2.BillingAccountUsageReportEntityData] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cost", b"cost", "credit_details", b"credit_details", "expense", b"expense"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cost", b"cost", "credit_details", b"credit_details", "currency", b"currency", "entities_data", b"entities_data", "expense", b"expense"]) -> None: ...

global___BillingAccountUsageReportResponse = BillingAccountUsageReportResponse

@typing.final
class CloudUsageReportResponse(google.protobuf.message.Message):
    """Response for usage report requests by cloud.

    Contains aggregated usage, cost, and credit information organized by cloud entities,
    with both summary totals and detailed breakdowns for each cloud.
    The response includes:
    1. Overall totals for the entire period (cost, credits, expense)
    2. Entity-level totals for each cloud
    3. Time series breakdown for each cloud according to the requested aggregation period
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CURRENCY_FIELD_NUMBER: builtins.int
    COST_FIELD_NUMBER: builtins.int
    CREDIT_DETAILS_FIELD_NUMBER: builtins.int
    EXPENSE_FIELD_NUMBER: builtins.int
    ENTITIES_DATA_FIELD_NUMBER: builtins.int
    currency: yandex.cloud.billing.usage_records.v1.common_types_pb2.Currency.ValueType
    """Currency code (e.g., "RUB", "USD") for all monetary values in the response.
    Determined by the billing account's settings.
    """
    @property
    def cost(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Total usage cost for the selected time period.
        This represents the raw cost before any credits or discounts are applied.
        Calculated based on the resource consumption and the corresponding price rates.
        """

    @property
    def credit_details(self) -> yandex.cloud.billing.usage_records.v1.credit_pb2.CreditDetails:
        """Total credits (monetary grants, volume incentives, committed use discounts, and free credits) applied in the selected period.
        Contains a detailed breakdown of all credit types that reduced the final billable amount.
        """

    @property
    def expense(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Total expense (including cost and credit) for the selected time period.
        This is the final billable amount after all credits have been applied.
        Formula: expense = cost - sum of all credits.
        """

    @property
    def entities_data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.billing.usage_records.v1.consumption_core_pb2.CloudUsageReportEntityData]:
        """Detailed usage and billing data for each cloud entity.
        This field contains a structured breakdown of costs, credits, and expenses
        for each individual cloud, including:
        1. Entity-level totals for the entire period (cost, credits, expense)
        2. Time series data broken down by the specified aggregation period (day/week/month/quarter/year)
        This represents the second and third levels in the overall three-level response structure.
        """

    def __init__(
        self,
        *,
        currency: yandex.cloud.billing.usage_records.v1.common_types_pb2.Currency.ValueType = ...,
        cost: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        credit_details: yandex.cloud.billing.usage_records.v1.credit_pb2.CreditDetails | None = ...,
        expense: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        entities_data: collections.abc.Iterable[yandex.cloud.billing.usage_records.v1.consumption_core_pb2.CloudUsageReportEntityData] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cost", b"cost", "credit_details", b"credit_details", "expense", b"expense"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cost", b"cost", "credit_details", b"credit_details", "currency", b"currency", "entities_data", b"entities_data", "expense", b"expense"]) -> None: ...

global___CloudUsageReportResponse = CloudUsageReportResponse

@typing.final
class FolderUsageReportResponse(google.protobuf.message.Message):
    """Response for usage report requests by folder.

    Contains aggregated usage, cost, and credit information organized by folder entities,
    with both summary totals and detailed breakdowns for each folder.
    The response includes:
    1. Overall totals for the entire period (cost, credits, expense)
    2. Entity-level totals for each folder
    3. Time series breakdown for each folder according to the requested aggregation period
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CURRENCY_FIELD_NUMBER: builtins.int
    COST_FIELD_NUMBER: builtins.int
    CREDIT_DETAILS_FIELD_NUMBER: builtins.int
    EXPENSE_FIELD_NUMBER: builtins.int
    ENTITIES_DATA_FIELD_NUMBER: builtins.int
    currency: yandex.cloud.billing.usage_records.v1.common_types_pb2.Currency.ValueType
    """Currency code (e.g., "RUB", "USD") for all monetary values in the response.
    Determined by the billing account's settings.
    """
    @property
    def cost(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Total usage cost for the selected time period.
        This represents the raw cost before any credits or discounts are applied.
        Calculated based on the resource consumption and the corresponding price rates.
        """

    @property
    def credit_details(self) -> yandex.cloud.billing.usage_records.v1.credit_pb2.CreditDetails:
        """Total credits (monetary grants, volume incentives, committed use discounts, and free credits) applied in the selected period.
        Contains a detailed breakdown of all credit types that reduced the final billable amount.
        """

    @property
    def expense(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Total expense (including cost and credit) for the selected time period.
        This is the final billable amount after all credits have been applied.
        Formula: expense = cost - sum of all credits.
        """

    @property
    def entities_data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.billing.usage_records.v1.consumption_core_pb2.FolderUsageReportEntityData]:
        """Detailed usage and billing data for each folder entity.
        This field contains a structured breakdown of costs, credits, and expenses
        for each individual folder, including:
        1. Entity-level totals for the entire period (cost, credits, expense)
        2. Time series data broken down by the specified aggregation period (day/week/month/quarter/year)
        This represents the second and third levels in the overall three-level response structure.
        """

    def __init__(
        self,
        *,
        currency: yandex.cloud.billing.usage_records.v1.common_types_pb2.Currency.ValueType = ...,
        cost: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        credit_details: yandex.cloud.billing.usage_records.v1.credit_pb2.CreditDetails | None = ...,
        expense: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        entities_data: collections.abc.Iterable[yandex.cloud.billing.usage_records.v1.consumption_core_pb2.FolderUsageReportEntityData] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cost", b"cost", "credit_details", b"credit_details", "expense", b"expense"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cost", b"cost", "credit_details", b"credit_details", "currency", b"currency", "entities_data", b"entities_data", "expense", b"expense"]) -> None: ...

global___FolderUsageReportResponse = FolderUsageReportResponse

@typing.final
class ServiceUsageReportResponse(google.protobuf.message.Message):
    """Response for usage report requests by service.

    Contains aggregated usage, cost, and credit information organized by service entities,
    with both summary totals and detailed breakdowns for each service. Services represent
    broad product categories (like Compute, Storage, AI) that can contain multiple SKUs.
    The response includes:
    1. Overall totals for the entire period (cost, credits, expense)
    2. Entity-level totals for each service
    3. Time series breakdown for each service according to the requested aggregation period
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CURRENCY_FIELD_NUMBER: builtins.int
    COST_FIELD_NUMBER: builtins.int
    CREDIT_DETAILS_FIELD_NUMBER: builtins.int
    EXPENSE_FIELD_NUMBER: builtins.int
    ENTITIES_DATA_FIELD_NUMBER: builtins.int
    currency: yandex.cloud.billing.usage_records.v1.common_types_pb2.Currency.ValueType
    """Currency code (e.g., "RUB", "USD") for all monetary values in the response.
    Determined by the billing account's settings.
    """
    @property
    def cost(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Total usage cost for the selected time period.
        This represents the raw cost before any credits or discounts are applied.
        Calculated based on the resource consumption and the corresponding price rates.
        """

    @property
    def credit_details(self) -> yandex.cloud.billing.usage_records.v1.credit_pb2.CreditDetails:
        """Total credits (monetary grants, volume incentives, committed use discounts, and free credits) applied in the selected period.
        Contains a detailed breakdown of all credit types that reduced the final billable amount.
        """

    @property
    def expense(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Total expense (including cost and credit) for the selected time period.
        This is the final billable amount after all credits have been applied.
        Formula: expense = cost - sum of all credits.
        """

    @property
    def entities_data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.billing.usage_records.v1.consumption_core_pb2.ServiceUsageReportEntityData]:
        """Detailed usage and billing data for each service entity.
        This field contains a structured breakdown of costs, credits, and expenses
        for each individual service, including:
        1. Entity-level totals for the entire period (cost, credits, expense)
        2. Time series data broken down by the specified aggregation period (day/week/month/quarter/year)
        This represents the second and third levels in the overall three-level response structure.
        """

    def __init__(
        self,
        *,
        currency: yandex.cloud.billing.usage_records.v1.common_types_pb2.Currency.ValueType = ...,
        cost: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        credit_details: yandex.cloud.billing.usage_records.v1.credit_pb2.CreditDetails | None = ...,
        expense: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        entities_data: collections.abc.Iterable[yandex.cloud.billing.usage_records.v1.consumption_core_pb2.ServiceUsageReportEntityData] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cost", b"cost", "credit_details", b"credit_details", "expense", b"expense"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cost", b"cost", "credit_details", b"credit_details", "currency", b"currency", "entities_data", b"entities_data", "expense", b"expense"]) -> None: ...

global___ServiceUsageReportResponse = ServiceUsageReportResponse

@typing.final
class SKUUsageReportResponse(google.protobuf.message.Message):
    """Response for usage report requests by SKU.

    Contains aggregated usage, cost, and credit information organized by SKU (Stock Keeping Unit) entities,
    with both summary totals and detailed breakdowns for each SKU. SKUs are specific billable offerings
    (like particular VM types or disk types) that belong to a parent service.
    The response includes:
    1. Overall totals for the entire period (cost, credits, expense)
    2. Entity-level totals for each SKU
    3. Time series breakdown for each SKU according to the requested aggregation period
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CURRENCY_FIELD_NUMBER: builtins.int
    COST_FIELD_NUMBER: builtins.int
    CREDIT_DETAILS_FIELD_NUMBER: builtins.int
    EXPENSE_FIELD_NUMBER: builtins.int
    ENTITIES_DATA_FIELD_NUMBER: builtins.int
    currency: yandex.cloud.billing.usage_records.v1.common_types_pb2.Currency.ValueType
    """Currency code (e.g., "RUB", "USD") for all monetary values in the response.
    Determined by the billing account's settings.
    """
    @property
    def cost(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Total usage cost for the selected time period.
        This represents the raw cost before any credits or discounts are applied.
        Calculated based on the resource consumption and the corresponding price rates.
        """

    @property
    def credit_details(self) -> yandex.cloud.billing.usage_records.v1.credit_pb2.CreditDetails:
        """Total credits (monetary grants, volume incentives, committed use discounts, and free credits) applied in the selected period.
        Contains a detailed breakdown of all credit types that reduced the final billable amount.
        """

    @property
    def expense(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Total expense (including cost and credit) for the selected time period.
        This is the final billable amount after all credits have been applied.
        Formula: expense = cost - sum of all credits.
        """

    @property
    def entities_data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.billing.usage_records.v1.consumption_core_pb2.SKUUsageReportEntityData]:
        """Detailed usage and billing data for each SKU entity.
        This field contains a structured breakdown of costs, credits, and expenses
        for each individual SKU, including:
        1. Entity-level totals for the entire period (cost, credits, expense, pricing_quantity)
        2. Time series data broken down by the specified aggregation period (day/week/month/quarter/year)
        This represents the second and third levels in the overall three-level response structure.
        """

    def __init__(
        self,
        *,
        currency: yandex.cloud.billing.usage_records.v1.common_types_pb2.Currency.ValueType = ...,
        cost: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        credit_details: yandex.cloud.billing.usage_records.v1.credit_pb2.CreditDetails | None = ...,
        expense: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        entities_data: collections.abc.Iterable[yandex.cloud.billing.usage_records.v1.consumption_core_pb2.SKUUsageReportEntityData] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cost", b"cost", "credit_details", b"credit_details", "expense", b"expense"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cost", b"cost", "credit_details", b"credit_details", "currency", b"currency", "entities_data", b"entities_data", "expense", b"expense"]) -> None: ...

global___SKUUsageReportResponse = SKUUsageReportResponse

@typing.final
class ResourceUsageReportResponse(google.protobuf.message.Message):
    """Response for usage report requests by resource.

    Contains aggregated usage, cost, and credit information organized by resource entities,
    with both summary totals and detailed breakdowns for each individual resource.
    The response includes:
    1. Overall totals for the entire period (cost, credits, expense)
    2. Entity-level totals for each resource
    3. Time series breakdown for each resource according to the requested aggregation period
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CURRENCY_FIELD_NUMBER: builtins.int
    COST_FIELD_NUMBER: builtins.int
    CREDIT_DETAILS_FIELD_NUMBER: builtins.int
    EXPENSE_FIELD_NUMBER: builtins.int
    ENTITIES_DATA_FIELD_NUMBER: builtins.int
    currency: yandex.cloud.billing.usage_records.v1.common_types_pb2.Currency.ValueType
    """Currency code (e.g., "RUB", "USD") for all monetary values in the response.
    Determined by the billing account's settings.
    """
    @property
    def cost(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Total usage cost for the selected time period.
        This represents the raw cost before any credits or discounts are applied.
        Calculated based on the resource consumption and the corresponding price rates.
        """

    @property
    def credit_details(self) -> yandex.cloud.billing.usage_records.v1.credit_pb2.CreditDetails:
        """Total credits (monetary grants, volume incentives, committed use discounts, and free credits) applied in the selected period.
        Contains a detailed breakdown of all credit types that reduced the final billable amount.
        """

    @property
    def expense(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Total expense (including cost and credit) for the selected time period.
        This is the final billable amount after all credits have been applied.
        Formula: expense = cost - sum of all credits.
        """

    @property
    def entities_data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.billing.usage_records.v1.consumption_core_pb2.ResourceUsageReportEntityData]:
        """Detailed usage and billing data for each resource entity.
        This field contains a structured breakdown of costs, credits, and expenses
        for each individual resource, including:
        1. Entity-level totals for the entire period (cost, credits, expense)
        2. Time series data broken down by the specified aggregation period (day/week/month/quarter/year)
        This represents the second and third levels in the overall three-level response structure.
        """

    def __init__(
        self,
        *,
        currency: yandex.cloud.billing.usage_records.v1.common_types_pb2.Currency.ValueType = ...,
        cost: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        credit_details: yandex.cloud.billing.usage_records.v1.credit_pb2.CreditDetails | None = ...,
        expense: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        entities_data: collections.abc.Iterable[yandex.cloud.billing.usage_records.v1.consumption_core_pb2.ResourceUsageReportEntityData] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cost", b"cost", "credit_details", b"credit_details", "expense", b"expense"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cost", b"cost", "credit_details", b"credit_details", "currency", b"currency", "entities_data", b"entities_data", "expense", b"expense"]) -> None: ...

global___ResourceUsageReportResponse = ResourceUsageReportResponse

@typing.final
class LabelKeyUsageReportResponse(google.protobuf.message.Message):
    """Response for usage report requests by label-based grouping.

    Contains aggregated usage, cost, and credit information organized by label key-value pairs
    (e.g., "env:prod", "team:finance"), with both summary totals and detailed breakdowns for each label group.
    This allows analyzing costs across custom business dimensions defined by user-attached labels.
    The response includes:
    1. Overall totals for the entire period (cost, credits, expense)
    2. Entity-level totals for each label key-value pair
    3. Time series breakdown for each label key-value pair according to the requested aggregation period
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CURRENCY_FIELD_NUMBER: builtins.int
    COST_FIELD_NUMBER: builtins.int
    CREDIT_DETAILS_FIELD_NUMBER: builtins.int
    EXPENSE_FIELD_NUMBER: builtins.int
    ENTITIES_DATA_FIELD_NUMBER: builtins.int
    currency: yandex.cloud.billing.usage_records.v1.common_types_pb2.Currency.ValueType
    """Currency code (e.g., "RUB", "USD") for all monetary values in the response.
    Determined by the billing account's settings.
    """
    @property
    def cost(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Total usage cost for the selected time period.
        This represents the raw cost before any credits or discounts are applied.
        Calculated based on the resource consumption and the corresponding price rates.
        """

    @property
    def credit_details(self) -> yandex.cloud.billing.usage_records.v1.credit_pb2.CreditDetails:
        """Total credits (monetary grants, volume incentives, committed use discounts, and free credits) applied in the selected period.
        Contains a detailed breakdown of all credit types that reduced the final billable amount.
        """

    @property
    def expense(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Total expense (including cost and credit) for the selected time period.
        This is the final billable amount after all credits have been applied.
        Formula: expense = cost - sum of all credits.
        """

    @property
    def entities_data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.billing.usage_records.v1.consumption_core_pb2.LabelUsageReportEntityData]:
        """Detailed usage and billing data for each label entity.
        This field contains a structured breakdown of costs, credits, and expenses
        for each individual label, including:
        1. Entity-level totals for the entire period (cost, credits, expense)
        2. Time series data broken down by the specified aggregation period (day/week/month/quarter/year)
        This represents the second and third levels in the overall three-level response structure.
        """

    def __init__(
        self,
        *,
        currency: yandex.cloud.billing.usage_records.v1.common_types_pb2.Currency.ValueType = ...,
        cost: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        credit_details: yandex.cloud.billing.usage_records.v1.credit_pb2.CreditDetails | None = ...,
        expense: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        entities_data: collections.abc.Iterable[yandex.cloud.billing.usage_records.v1.consumption_core_pb2.LabelUsageReportEntityData] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cost", b"cost", "credit_details", b"credit_details", "expense", b"expense"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cost", b"cost", "credit_details", b"credit_details", "currency", b"currency", "entities_data", b"entities_data", "expense", b"expense"]) -> None: ...

global___LabelKeyUsageReportResponse = LabelKeyUsageReportResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/trino/v1/resource_management.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/trino/v1/resource_management.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/trino/v1/resource_management.proto\x12\x15yandex.cloud.trino.v1\x1a\x1dyandex/cloud/validation.proto\"\x93\x01\n\x18ResourceManagementConfig\x12\x44\n\x0fresource_groups\x18\x01 \x01(\x0b\x32+.yandex.cloud.trino.v1.ResourceGroupsConfig\x12\x31\n\x05query\x18\x02 \x01(\x0b\x32\".yandex.cloud.trino.v1.QueryConfig\"\x88\x01\n\x0bQueryConfig\x12\x46\n\nproperties\x18\x01 \x03(\x0b\x32\x32.yandex.cloud.trino.v1.QueryConfig.PropertiesEntry\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbf\x01\n\x14ResourceGroupsConfig\x12G\n\x0broot_groups\x18\x01 \x03(\x0b\x32*.yandex.cloud.trino.v1.ResourceGroupConfigB\x06\x82\xc8\x31\x02>0\x12\x44\n\tselectors\x18\x02 \x03(\x0b\x32).yandex.cloud.trino.v1.SelectorRuleConfigB\x06\x82\xc8\x31\x02>0\x12\x18\n\x10\x63pu_quota_period\x18\x03 \x01(\t\"\x87\x04\n\x13ResourceGroupConfig\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1a\n\nmax_queued\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\x12\x1e\n\x16soft_concurrency_limit\x18\x03 \x01(\x03\x12&\n\x16hard_concurrency_limit\x18\x04 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\x12\x19\n\x11soft_memory_limit\x18\x05 \x01(\t\x12\x16\n\x0esoft_cpu_limit\x18\x06 \x01(\t\x12\x16\n\x0ehard_cpu_limit\x18\x07 \x01(\t\x12V\n\x11scheduling_policy\x18\x08 \x01(\x0e\x32;.yandex.cloud.trino.v1.ResourceGroupConfig.SchedulingPolicy\x12\x19\n\x11scheduling_weight\x18\t \x01(\x03\x12>\n\nsub_groups\x18\x0b \x03(\x0b\x32*.yandex.cloud.trino.v1.ResourceGroupConfig\"t\n\x10SchedulingPolicy\x12!\n\x1dSCHEDULING_POLICY_UNSPECIFIED\x10\x00\x12\x08\n\x04\x46\x41IR\x10\x01\x12\x0c\n\x08WEIGHTED\x10\x02\x12\x11\n\rWEIGHTED_FAIR\x10\x03\x12\x12\n\x0eQUERY_PRIORITY\x10\x04J\x04\x08\n\x10\x0b\"\x80\x03\n\x12SelectorRuleConfig\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x12\n\nuser_group\x18\x04 \x01(\t\x12\x0e\n\x06source\x18\x05 \x01(\t\x12G\n\nquery_type\x18\x06 \x01(\x0e\x32\x33.yandex.cloud.trino.v1.SelectorRuleConfig.QueryType\x12\x13\n\x0b\x63lient_tags\x18\x07 \x03(\t\x12\x13\n\x05group\x18\x08 \x01(\tB\x04\xe8\xc7\x31\x01\"\xb8\x01\n\tQueryType\x12\x1a\n\x16QUERY_TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06SELECT\x10\x01\x12\x0b\n\x07\x45XPLAIN\x10\x02\x12\x0c\n\x08\x44\x45SCRIBE\x10\x03\x12\n\n\x06INSERT\x10\x04\x12\n\n\x06UPDATE\x10\x05\x12\t\n\x05MERGE\x10\x06\x12\n\n\x06\x44\x45LETE\x10\x07\x12\x0b\n\x07\x41NALYZE\x10\x08\x12\x13\n\x0f\x44\x41TA_DEFINITION\x10\t\x12\x17\n\x13\x41LTER_TABLE_EXECUTE\x10\nJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04\x42\\\n\x19yandex.cloud.api.trino.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/trino/v1;trinob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.trino.v1.resource_management_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031yandex.cloud.api.trino.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/trino/v1;trino'
  _globals['_QUERYCONFIG_PROPERTIESENTRY']._loaded_options = None
  _globals['_QUERYCONFIG_PROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_RESOURCEGROUPSCONFIG'].fields_by_name['root_groups']._loaded_options = None
  _globals['_RESOURCEGROUPSCONFIG'].fields_by_name['root_groups']._serialized_options = b'\202\3101\002>0'
  _globals['_RESOURCEGROUPSCONFIG'].fields_by_name['selectors']._loaded_options = None
  _globals['_RESOURCEGROUPSCONFIG'].fields_by_name['selectors']._serialized_options = b'\202\3101\002>0'
  _globals['_RESOURCEGROUPCONFIG'].fields_by_name['name']._loaded_options = None
  _globals['_RESOURCEGROUPCONFIG'].fields_by_name['name']._serialized_options = b'\350\3071\001'
  _globals['_RESOURCEGROUPCONFIG'].fields_by_name['max_queued']._loaded_options = None
  _globals['_RESOURCEGROUPCONFIG'].fields_by_name['max_queued']._serialized_options = b'\372\3071\002>0'
  _globals['_RESOURCEGROUPCONFIG'].fields_by_name['hard_concurrency_limit']._loaded_options = None
  _globals['_RESOURCEGROUPCONFIG'].fields_by_name['hard_concurrency_limit']._serialized_options = b'\372\3071\002>0'
  _globals['_SELECTORRULECONFIG'].fields_by_name['group']._loaded_options = None
  _globals['_SELECTORRULECONFIG'].fields_by_name['group']._serialized_options = b'\350\3071\001'
  _globals['_RESOURCEMANAGEMENTCONFIG']._serialized_start=106
  _globals['_RESOURCEMANAGEMENTCONFIG']._serialized_end=253
  _globals['_QUERYCONFIG']._serialized_start=256
  _globals['_QUERYCONFIG']._serialized_end=392
  _globals['_QUERYCONFIG_PROPERTIESENTRY']._serialized_start=343
  _globals['_QUERYCONFIG_PROPERTIESENTRY']._serialized_end=392
  _globals['_RESOURCEGROUPSCONFIG']._serialized_start=395
  _globals['_RESOURCEGROUPSCONFIG']._serialized_end=586
  _globals['_RESOURCEGROUPCONFIG']._serialized_start=589
  _globals['_RESOURCEGROUPCONFIG']._serialized_end=1108
  _globals['_RESOURCEGROUPCONFIG_SCHEDULINGPOLICY']._serialized_start=986
  _globals['_RESOURCEGROUPCONFIG_SCHEDULINGPOLICY']._serialized_end=1102
  _globals['_SELECTORRULECONFIG']._serialized_start=1111
  _globals['_SELECTORRULECONFIG']._serialized_end=1495
  _globals['_SELECTORRULECONFIG_QUERYTYPE']._serialized_start=1299
  _globals['_SELECTORRULECONFIG_QUERYTYPE']._serialized_end=1483
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/cloudregistry/v1/lifecycle_policy_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/cloudregistry/v1/lifecycle_policy_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.cloudregistry.v1 import lifecycle_policy_pb2 as yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_lifecycle__policy__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<yandex/cloud/cloudregistry/v1/lifecycle_policy_service.proto\x12\x1dyandex.cloud.cloudregistry.v1\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x34yandex/cloud/cloudregistry/v1/lifecycle_policy.proto\x1a google/protobuf/field_mask.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\"\x94\x02\n\x1c\x43reateLifecyclePolicyRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12;\n\x05rules\x18\x04 \x03(\x0b\x32,.yandex.cloud.cloudregistry.v1.LifecycleRule\x12\x42\n\x05state\x18\x05 \x01(\x0e\x32\x33.yandex.cloud.cloudregistry.v1.LifecyclePolicyState\"2\n\x1d\x43reateLifecyclePolicyMetadata\x12\x11\n\tpolicy_id\x18\x01 \x01(\t\"\xc3\x02\n\x1cUpdateLifecyclePolicyRequest\x12\x1f\n\tpolicy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1f\n\x0b\x64\x65scription\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12;\n\x05rules\x18\x05 \x03(\x0b\x32,.yandex.cloud.cloudregistry.v1.LifecycleRule\x12\x42\n\x05state\x18\x06 \x01(\x0e\x32\x33.yandex.cloud.cloudregistry.v1.LifecyclePolicyState\"@\n\x1dUpdateLifecyclePolicyMetadata\x12\x1f\n\tpolicy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"?\n\x1c\x44\x65leteLifecyclePolicyRequest\x12\x1f\n\tpolicy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"@\n\x1d\x44\x65leteLifecyclePolicyMetadata\x12\x1f\n\tpolicy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"<\n\x19GetLifecyclePolicyRequest\x12\x1f\n\tpolicy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"x\n\x1aListLifecyclePolicyRequest\x12\x1d\n\x0bregistry_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1c\n\tpage_size\x18\x02 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"x\n\x1bListLifecyclePolicyResponse\x12@\n\x08policies\x18\x01 \x03(\x0b\x32..yandex.cloud.cloudregistry.v1.LifecyclePolicy\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x8e\x01\n!ChangeLifecyclePolicyStateRequest\x12\x1f\n\tpolicy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12H\n\x05state\x18\x02 \x01(\x0e\x32\x33.yandex.cloud.cloudregistry.v1.LifecyclePolicyStateB\x04\xe8\xc7\x31\x01\x32\xb0\t\n\x16LifecyclePolicyService\x12\xcd\x01\n\x06\x43reate\x12;.yandex.cloud.cloudregistry.v1.CreateLifecyclePolicyRequest\x1a!.yandex.cloud.operation.Operation\"c\xb2\xd2*0\n\x1d\x43reateLifecyclePolicyMetadata\x12\x0fLifecyclePolicy\x82\xd3\xe4\x93\x02)\"$/cloud-registry/v1/lifecyclePolicies:\x01*\x12\xd9\x01\n\x06Update\x12;.yandex.cloud.cloudregistry.v1.UpdateLifecyclePolicyRequest\x1a!.yandex.cloud.operation.Operation\"o\xb2\xd2*0\n\x1dUpdateLifecyclePolicyMetadata\x12\x0fLifecyclePolicy\x82\xd3\xe4\x93\x02\x35\x32\x30/cloud-registry/v1/lifecyclePolicies/{policy_id}:\x01*\x12\xdc\x01\n\x06\x44\x65lete\x12;.yandex.cloud.cloudregistry.v1.DeleteLifecyclePolicyRequest\x1a!.yandex.cloud.operation.Operation\"r\xb2\xd2*6\n\x1d\x44\x65leteLifecyclePolicyMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x32*0/cloud-registry/v1/lifecyclePolicies/{policy_id}\x12\xa9\x01\n\x03Get\x12\x38.yandex.cloud.cloudregistry.v1.GetLifecyclePolicyRequest\x1a..yandex.cloud.cloudregistry.v1.LifecyclePolicy\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/cloud-registry/v1/lifecyclePolicies/{policy_id}\x12\xab\x01\n\x04List\x12\x39.yandex.cloud.cloudregistry.v1.ListLifecyclePolicyRequest\x1a:.yandex.cloud.cloudregistry.v1.ListLifecyclePolicyResponse\",\x82\xd3\xe4\x93\x02&\x12$/cloud-registry/v1/lifecyclePolicies\x12\xb0\x01\n\x0b\x43hangeState\x12@.yandex.cloud.cloudregistry.v1.ChangeLifecyclePolicyStateRequest\x1a\x16.google.protobuf.Empty\"G\x82\xd3\xe4\x93\x02\x41\"</cloud-registry/v1/lifecyclePolicies/{policy_id}:changeState:\x01*Bt\n!yandex.cloud.api.cloudregistry.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/cloudregistry/v1;cloudregistryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cloudregistry.v1.lifecycle_policy_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!yandex.cloud.api.cloudregistry.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/cloudregistry/v1;cloudregistry'
  _globals['_CREATELIFECYCLEPOLICYREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_CREATELIFECYCLEPOLICYREQUEST'].fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATELIFECYCLEPOLICYREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATELIFECYCLEPOLICYREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _globals['_CREATELIFECYCLEPOLICYREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATELIFECYCLEPOLICYREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _globals['_UPDATELIFECYCLEPOLICYREQUEST'].fields_by_name['policy_id']._loaded_options = None
  _globals['_UPDATELIFECYCLEPOLICYREQUEST'].fields_by_name['policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATELIFECYCLEPOLICYREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATELIFECYCLEPOLICYREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _globals['_UPDATELIFECYCLEPOLICYREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATELIFECYCLEPOLICYREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _globals['_UPDATELIFECYCLEPOLICYMETADATA'].fields_by_name['policy_id']._loaded_options = None
  _globals['_UPDATELIFECYCLEPOLICYMETADATA'].fields_by_name['policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETELIFECYCLEPOLICYREQUEST'].fields_by_name['policy_id']._loaded_options = None
  _globals['_DELETELIFECYCLEPOLICYREQUEST'].fields_by_name['policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETELIFECYCLEPOLICYMETADATA'].fields_by_name['policy_id']._loaded_options = None
  _globals['_DELETELIFECYCLEPOLICYMETADATA'].fields_by_name['policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETLIFECYCLEPOLICYREQUEST'].fields_by_name['policy_id']._loaded_options = None
  _globals['_GETLIFECYCLEPOLICYREQUEST'].fields_by_name['policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTLIFECYCLEPOLICYREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_LISTLIFECYCLEPOLICYREQUEST'].fields_by_name['registry_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTLIFECYCLEPOLICYREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTLIFECYCLEPOLICYREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0050-100'
  _globals['_LISTLIFECYCLEPOLICYREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTLIFECYCLEPOLICYREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_CHANGELIFECYCLEPOLICYSTATEREQUEST'].fields_by_name['policy_id']._loaded_options = None
  _globals['_CHANGELIFECYCLEPOLICYSTATEREQUEST'].fields_by_name['policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CHANGELIFECYCLEPOLICYSTATEREQUEST'].fields_by_name['state']._loaded_options = None
  _globals['_CHANGELIFECYCLEPOLICYSTATEREQUEST'].fields_by_name['state']._serialized_options = b'\350\3071\001'
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*0\n\035CreateLifecyclePolicyMetadata\022\017LifecyclePolicy\202\323\344\223\002)\"$/cloud-registry/v1/lifecyclePolicies:\001*'
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*0\n\035UpdateLifecyclePolicyMetadata\022\017LifecyclePolicy\202\323\344\223\002520/cloud-registry/v1/lifecyclePolicies/{policy_id}:\001*'
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*6\n\035DeleteLifecyclePolicyMetadata\022\025google.protobuf.Empty\202\323\344\223\0022*0/cloud-registry/v1/lifecyclePolicies/{policy_id}'
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0022\0220/cloud-registry/v1/lifecyclePolicies/{policy_id}'
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002&\022$/cloud-registry/v1/lifecyclePolicies'
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['ChangeState']._loaded_options = None
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['ChangeState']._serialized_options = b'\202\323\344\223\002A\"</cloud-registry/v1/lifecyclePolicies/{policy_id}:changeState:\001*'
  _globals['_CREATELIFECYCLEPOLICYREQUEST']._serialized_start=348
  _globals['_CREATELIFECYCLEPOLICYREQUEST']._serialized_end=624
  _globals['_CREATELIFECYCLEPOLICYMETADATA']._serialized_start=626
  _globals['_CREATELIFECYCLEPOLICYMETADATA']._serialized_end=676
  _globals['_UPDATELIFECYCLEPOLICYREQUEST']._serialized_start=679
  _globals['_UPDATELIFECYCLEPOLICYREQUEST']._serialized_end=1002
  _globals['_UPDATELIFECYCLEPOLICYMETADATA']._serialized_start=1004
  _globals['_UPDATELIFECYCLEPOLICYMETADATA']._serialized_end=1068
  _globals['_DELETELIFECYCLEPOLICYREQUEST']._serialized_start=1070
  _globals['_DELETELIFECYCLEPOLICYREQUEST']._serialized_end=1133
  _globals['_DELETELIFECYCLEPOLICYMETADATA']._serialized_start=1135
  _globals['_DELETELIFECYCLEPOLICYMETADATA']._serialized_end=1199
  _globals['_GETLIFECYCLEPOLICYREQUEST']._serialized_start=1201
  _globals['_GETLIFECYCLEPOLICYREQUEST']._serialized_end=1261
  _globals['_LISTLIFECYCLEPOLICYREQUEST']._serialized_start=1263
  _globals['_LISTLIFECYCLEPOLICYREQUEST']._serialized_end=1383
  _globals['_LISTLIFECYCLEPOLICYRESPONSE']._serialized_start=1385
  _globals['_LISTLIFECYCLEPOLICYRESPONSE']._serialized_end=1505
  _globals['_CHANGELIFECYCLEPOLICYSTATEREQUEST']._serialized_start=1508
  _globals['_CHANGELIFECYCLEPOLICYSTATEREQUEST']._serialized_end=1650
  _globals['_LIFECYCLEPOLICYSERVICE']._serialized_start=1653
  _globals['_LIFECYCLEPOLICYSERVICE']._serialized_end=2853
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/iam/v1/access_policy_template_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/iam/v1/access_policy_template_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8yandex/cloud/iam/v1/access_policy_template_service.proto\x12\x13yandex.cloud.iam.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/access/access.proto\x1a\x1dyandex/cloud/validation.proto\"a\n ListAccessPolicyTemplatesRequest\x12\x1d\n\tpage_size\x18\x03 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"\x80\x01\n!ListAccessPolicyTemplatesResponse\x12\x42\n\x17\x61\x63\x63\x65ss_policy_templates\x18\x01 \x03(\x0b\x32!.yandex.cloud.access.AccessPolicy\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xbc\x01\n\x1b\x41\x63\x63\x65ssPolicyTemplateService\x12\x9c\x01\n\x04List\x12\x35.yandex.cloud.iam.v1.ListAccessPolicyTemplatesRequest\x1a\x36.yandex.cloud.iam.v1.ListAccessPolicyTemplatesResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/iam/v1/accessPolicyTemplatesBV\n\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.access_policy_template_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iam'
  _globals['_LISTACCESSPOLICYTEMPLATESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTACCESSPOLICYTEMPLATESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTACCESSPOLICYTEMPLATESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTACCESSPOLICYTEMPLATESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_ACCESSPOLICYTEMPLATESERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_ACCESSPOLICYTEMPLATESERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\037\022\035/iam/v1/accessPolicyTemplates'
  _globals['_LISTACCESSPOLICYTEMPLATESREQUEST']._serialized_start=176
  _globals['_LISTACCESSPOLICYTEMPLATESREQUEST']._serialized_end=273
  _globals['_LISTACCESSPOLICYTEMPLATESRESPONSE']._serialized_start=276
  _globals['_LISTACCESSPOLICYTEMPLATESRESPONSE']._serialized_end=404
  _globals['_ACCESSPOLICYTEMPLATESERVICE']._serialized_start=407
  _globals['_ACCESSPOLICYTEMPLATESERVICE']._serialized_end=595
# @@protoc_insertion_point(module_scope)
